Overview: module code — Surprise 1 documentation

# All modules for which code is available

- surprise.accuracy
- surprise.dataset
- surprise.dump
- surprise.evaluate
- surprise.model_selection.search
- surprise.model_selection.split
- surprise.model_selection.validation
- surprise.prediction_algorithms.algo_base
- surprise.prediction_algorithms.baseline_only
- surprise.prediction_algorithms.co_clustering
- surprise.prediction_algorithms.knns
- surprise.prediction_algorithms.matrix_factorization
- surprise.prediction_algorithms.predictions
- surprise.prediction_algorithms.random_pred
- surprise.prediction_algorithms.slope_one
- surprise.reader
- surprise.similarities
- surprise.trainset